@@ -1,35 +1,29 @@
-#' Description: Generic Early Warning Signals
+#' Generic Early Warning Signals
 #'
-#' \code{generic_ews} is used to estimate statistical moments within rolling windows along a timeserie
+#' \code{\link{generic_ews}} is used to estimate statistical moments within rolling windows along a timeseries.
 #'
-# Details:
-#' see ref below
-#'
-# Arguments:
-#'    @param timeseries a numeric vector of the observed univariate timeseries values or a numeric matrix where the first column represents the time index and the second the observed timeseries values. Use vectors/matrices with headings. If the powerspectrum is to be plotted as well, the timeseries lenght should be even number.
-#'    @param winsize is the size of the rolling window expressed as percentage of the timeseries length (must be numeric between 0 and 100). Default is 50\%.
-#'    @param bandwidth is the bandwidth used for the Gaussian kernel when gaussian filtering is applied. It is expressed as percentage of the timeseries length (must be numeric between 0 and 100). Alternatively it can be given by the bandwidth selector \code{\link{bw.nrd0}} (Default).
-#'    @param detrending the timeseries can be detrended/filtered prior to analysis. There are four options: \code{gaussian} filtering, \code{loess} fitting, \code{linear} detrending and \code{first-differencing}. Default is \code{no} detrending.
-#'    @param span parameter that controls the degree of smoothing (numeric between 0 and 100, Default 25). see more on loess{stats}
-#'    @param degree the degree of polynomial to be used for when loess fitting is applied, normally 1 or 2 (Default). see more on loess{stats}
-#'    @param logtransform logical. If TRUE data are logtransformed prior to analysis as log(X+1). Default is FALSE.
-#'    @param interpolate logical. If TRUE linear interpolation is applied to produce a timeseries of equal length as the original. Default is FALSE (assumes there are no gaps in the timeseries).
-#'    @param AR_n logical. If TRUE the best fitted AR(n) model is fitted to the data. Default is FALSE.
-#'    @param powerspectrum logical. If TRUE the power spectrum within each rolling window is plotted. Default is FALSE. 
+#' @param timeseries a numeric vector of the observed univariate timeseries values or a numeric matrix where the first column represents the time index and the second the observed timeseries values. Use vectors/matrices with headings. If the powerspectrum is to be plotted as well, the timeseries lenght should be even number.
+#' @param winsize is the size of the rolling window expressed as percentage of the timeseries length (must be numeric between 0 and 100). Default is 50\%.
+#' @param bandwidth for the Gaussian kernel when gaussian filtering is applied. It is expressed as percentage of the timeseries length (must be numeric between 0 and 100). Alternatively it can be given by the bandwidth selector bw.nrd0 (Default).
+#' @param detrending the timeseries can be detrended/filtered prior to analysis. There are four options: gaussian filtering, loess fitting, linear detrending and first-differencing. Default is no detrending.
+#' @param span parameter that controls the degree of smoothing (numeric between 0 and 100, Default 25). 
+#' @param degree the degree of polynomial to be used for when loess fitting is applied, normally 1 or 2 (Default). 
+#' @param logtransform logical. If TRUE data are logtransformed prior to analysis as log(X+1). Default is FALSE.
+#' @param interpolate logical. If TRUE linear interpolation is applied to produce a timeseries of equal length as the original. Default is FALSE (assumes there are no gaps in the timeseries).
+#' @param AR_n logical. If TRUE the best fitted AR(n) model is fitted to the data. Default is FALSE.
+#' @param powerspectrum logical. If TRUE the power spectrum within each rolling window is plotted. Default is FALSE. 
 #' 
-# Returns:
-#'   @return \code{generic_ews} returns a matrix that contains:
-#'   @return \item{tim}{the time index.}
-#'   @return \item{ar1}{the \code{autoregressive coefficient ar(1)} of a first order AR model fitted on the data within the rolling window.}
-#'   @return \item{sd}{the \code{standard deviation} of the data estimated within each rolling window.}
-#'   @return \item{sk}{the \code{skewness} of the data estimated within each rolling window.}
-#'   @return \item{kurt}{the \code{kurtosis} of the data estimated within each rolling window.}
-#'   @return \item{cv}{the \code{coefficient of variation} of the data estimated within each rolling window.}
-#'   @return \item{returnrate}{the return rate of the data estimated as \code{1-ar(1)} cofficient within each rolling window.}
-#'   @return \item{densratio}{the \code{density ratio} of the power spectrum of the data estimated as the ratio of low frequencies over high frequencies within each rolling window.}
-#'   @return \item{acf1}{the \code{autocorrelation at first lag} of the data estimated within each rolling window.}
+#' @return \code{\link{generic_ews}} returns a matrix that contains:
+#'   tim the time index.
+#'   ar1 the autoregressive coefficient ar(1) of a first order AR model fitted on the data within the rolling window.
+#'   sd the standard deviation of the data estimated within each rolling window.
+#'   sk the skewness of the data estimated within each rolling window.
+#'   kurt the kurtosis of the data estimated within each rolling window.
+#'   cv the coefficient of variation of the data estimated within each rolling window.
+#'   returnrate the return rate of the data estimated as 1-ar(1) cofficient within each rolling window.
+#'   densratio the density ratio of the power spectrum of the data estimated as the ratio of low frequencies over high frequencies within each rolling window; acf1 the autocorrelation at first lag of the data estimated within each rolling window.
 #'
-#' In addition, \code{generic_ews} returns three plots. The first plot contains the original data, the detrending/filtering applied and the residuals (if selected), and all the moment statistics. For each statistic trends are estimated by the nonparametric Kendall tau correlation.  The second plot, if asked, quantifies resilience indicators fitting AR(n) selected by the Akaike Information Criterion. The third plot, if asked, is the power spectrum estimated by \code{\link{spec.ar}} for all frequencies within each rolling window.
+#' @details In addition, \code{\link{generic_ews}} returns three plots. The first plot contains the original data, the detrending/filtering applied and the residuals (if selected), and all the moment statistics. For each statistic trends are estimated by the nonparametric Kendall tau correlation. The second plot, if asked, quantifies resilience indicators fitting AR(n) selected by the Akaike Information Criterion. The third plot, if asked, is the power spectrum estimated by spec.ar for all frequencies within each rolling window.
 #'  
 #' @export
 #' 
@@ -39,8 +33,6 @@
 #' Dakos, V., et al (2008). 'Slowing down as an early warning signal for abrupt climate change.' \emph{Proceedings of the National Academy of Sciences} 105(38): 14308-14312 
 #' 
 #' Dakos, V., et al (2012).'Methods for Detecting Early Warnings of Critical Transitions in Time Series Illustrated Using Simulated Ecological Data.' \emph{PLoS ONE} 7(7): e41010. doi:10.1371/journal.pone.0041010 
-#' @seealso \code{\link{generic_ews}}; \code{\link{ddjnonparam_ews}}; \code{\link{bdstest_ews}}; \code{\link{sensitivity_ews}}; \code{\link{surrogates_ews}}; \code{\link{ch_ews}}; \code{\link{movpotential_ews}}; \code{\link{livpotential_ews}}; 
-#'
 #' @importFrom moments skewness
 #' @importFrom moments kurtosis
 #'
@@ -49,15 +41,12 @@
 #' out=generic_ews(foldbif,winsize=50,detrending='gaussian',
 #' bandwidth=5,logtransform=FALSE,interpolate=FALSE)
 #' @keywords early-warning
-
-# Author: Vasilis Dakos, January 2, 2012
-
 generic_ews <- function(timeseries, winsize = 50, detrending = c("no", "gaussian", 
     "loess", "linear", "first-diff"), bandwidth = NULL, span = NULL, degree = NULL, 
     logtransform = FALSE, interpolate = FALSE, AR_n = FALSE, powerspectrum = FALSE) {
     
     # timeseries<-ts(timeseries)
-    timeseries <- data.matrix(timeseries)  #strict data-types the input data as tseries object for use in later steps
+    timeseries <- as.matrix(timeseries)  #strict data-types the input data as tseries object for use in later steps
     if (dim(timeseries)[2] == 1) {
         Y = timeseries
         timeindex = 1:dim(timeseries)[1]
@@ -123,8 +112,8 @@ generic_ews <- function(timeseries, winsize = 50, detrending = c("no", "gaussian
     # Rearrange data for indicator calculation
     mw <- round(length(Y) * winsize/100)
     omw <- length(nsmY) - mw + 1  ##number of moving windows
-    low <- 6
-    high <- omw
+    low <- 2
+    high <- mw
     nMR <- matrix(data = NA, nrow = mw, ncol = omw)
     x1 <- 1:mw
     for (i in 1:omw) {
@@ -139,7 +128,7 @@ generic_ews <- function(timeseries, winsize = 50, detrending = c("no", "gaussian
     nKURT <- numeric()
     nACF <- numeric()
     nDENSITYRATIO <- numeric()
-    nSPECT <- matrix(0, nrow = omw, ncol = ncol(nMR))
+    nSPECT <- matrix(0, nrow = mw, ncol = ncol(nMR))
     nCV <- numeric()
     smARall <- numeric()
     smARmaxeig <- numeric()
@@ -148,7 +137,7 @@ generic_ews <- function(timeseries, winsize = 50, detrending = c("no", "gaussian
     
     nSD <- apply(nMR, 2, sd, na.rm = TRUE)
     for (i in 1:ncol(nMR)) {
-        nYR <- ar.ols(nMR[, i], aic = FALSE, order.max = 1, dmean = FALSE, intercept = FALSE)
+        nYR <- ar.ols(nMR[, i], aic = FALSE, order.max = 1, demean = TRUE, intercept = FALSE)
         nARR[i] <- nYR$ar
         # nSD[i]<-sapply(nMR[,i], sd, na.rm = TRUE)#sd(nMR[,i], na.rm = TRUE)
         nSK[i] <- abs(moments::skewness(nMR[, i], na.rm = TRUE))
@@ -156,7 +145,7 @@ generic_ews <- function(timeseries, winsize = 50, detrending = c("no", "gaussian
         nCV[i] <- nSD[i]/mean(nMR[, i])
         ACF <- acf(nMR[, i], lag.max = 1, type = c("correlation"), plot = FALSE)
         nACF[i] <- ACF$acf[2]
-        spectfft <- spec.ar(nMR[, i], n.freq = omw, plot = FALSE, order = 1)
+        spectfft <- spec.ar(nMR[, i], n.freq = mw, plot = FALSE, order = 1)
         nSPECT[, i] <- spectfft$spec
         nDENSITYRATIO[i] <- spectfft$spec[low]/spectfft$spec[high]
         
@@ -306,7 +295,7 @@ generic_ews <- function(timeseries, winsize = 50, detrending = c("no", "gaussian
     
     # Output
     out <- data.frame(timeindex[mw:length(nsmY)], nARR, nSD, nSK, nKURT, nCV, nRETURNRATE, 
-        nDENSITYRATIO, nACF)
+        nDENSITYRATIO, nACF,row.names = NULL)
     colnames(out) <- c("timeindex", "ar1", "sd", "sk", "kurt", "cv", "returnrate", 
         "densratio", "acf1")
     return(out)
